@@ -1,8 +1,8 @@
 WMTR <-
-function (fname = "Cloud.dat", fdir = getwd()) 
+function (fname = "Cloud.dat", fdir = getwd(), bound = 0) 
 {
     .C("ComputeWMTR", as.character(fname), as.character(paste(fdir, 
-        "/", sep = "")), PACKAGE = "WMTregions")
+        "/", sep = "")), as.integer(bound), PACKAGE = "WMTregions")
     "The trimmed region has been successfully calculated!"
 }
 
